summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qcanvaspixmap_imp.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-05 15:55:57 -0600
commit9ba04742771370f59740e32e11c5f3a1e6a1b70a (patch)
treec81c34dae2b3b1ea73801bf18a960265dc4207f7 /kjsembed/qtbindings/qcanvaspixmap_imp.h
parent1a96c45b22d01378202d9dc7ed9c47acd30f966e (diff)
downloadtdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.tar.gz
tdebindings-9ba04742771370f59740e32e11c5f3a1e6a1b70a.zip
Initial TQt conversion
Diffstat (limited to 'kjsembed/qtbindings/qcanvaspixmap_imp.h')
-rw-r--r--kjsembed/qtbindings/qcanvaspixmap_imp.h20
1 files changed, 10 insertions, 10 deletions
diff --git a/kjsembed/qtbindings/qcanvaspixmap_imp.h b/kjsembed/qtbindings/qcanvaspixmap_imp.h
index 607ff4d4..958c5dda 100644
--- a/kjsembed/qtbindings/qcanvaspixmap_imp.h
+++ b/kjsembed/qtbindings/qcanvaspixmap_imp.h
@@ -9,7 +9,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
-class TQCanvasPixmap;
+class TTQCanvasPixmap;
/**
* Namespace containing the KJSEmbed library.
@@ -17,11 +17,11 @@ class TQCanvasPixmap;
namespace KJSEmbed {
/**
* Wrapper class for TQCanvasPixmap methods.
*
* @author Richard Moore, rich@kde.org
*/
-class QCanvasPixmapImp : public JSProxyImp
+class TQCanvasPixmapImp : public JSProxyImp
{
public:
/** Enumerates the constructors supported by this class. */
@@ -42,8 +42,8 @@ public:
Method_Last = -1
};
- QCanvasPixmapImp( KJS::ExecState *exec, int id, bool constructor=false );
- ~QCanvasPixmapImp();
+ TQCanvasPixmapImp( KJS::ExecState *exec, int id, bool constructor=false );
+ ~TQCanvasPixmapImp();
/**
* Adds the static bindings for this class to the specified Object. The
@@ -57,15 +57,15 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TQCanvasPixmap *toQCanvasPixmap( KJS::Object &object );
+ static TTQCanvasPixmap *toTQCanvasPixmap( KJS::Object &object );
//
// Constructors implemented by this class.
//
- KJS::Object QCanvasPixmap_1( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasPixmap_2( KJS::ExecState *exec, const KJS::List &args );
- KJS::Object QCanvasPixmap_3( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPixmap_1( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPixmap_2( KJS::ExecState *exec, const KJS::List &args );
+ KJS::Object TQCanvasPixmap_3( KJS::ExecState *exec, const KJS::List &args );
//
// Methods implemented by this class.
@@ -92,7 +92,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TQCanvasPixmap *instance; // Temp
+ TTQCanvasPixmap *instance; // Temp
int id;
bool cons;
};
@@ -17,11 +17,11 @@ class TQCanvasPixmap;
namespace KJSEmbed {
/**
- * Wrapper class for TQCanvasPixmap methods.
+ * Wrapper class for TTQCanvasPixmap methods.
*
* @author Richard Moore, rich@kde.org